# Third-Party Licenses

This project includes third-party software components that are licensed separately. Below is a list of dependencies and their respective licenses.

## Sentence Transformers

- **Repository:** [UKPLab/sentence-transformers](https://github.com/UKPLab/sentence-transformers)
- **License:** Apache License 2.0
- **Copyright:** 2019 Nils Reimers
- **License Text:** See [LICENSE](https://github.com/UKPLab/sentence-transformers/blob/master/LICENSE)

## scikit-learn

- **Repository:** [scikit-learn/scikit-learn](https://github.com/scikit-learn/scikit-learn)
- **License:** BSD 3-Clause License
- **Copyright:** 2007 The scikit-learn developers.
- **License Text:** See [LICENSE](https://github.com/scikit-learn/scikit-learn/blob/main/COPYING)

